@@ -1,6 +1,4 @@
-"""
-Submodule for NeuroKit.
-"""
+"""Submodule for NeuroKit."""
 import functools
 
 from .complexity_delay import complexity_delay
