@@ -3,8 +3,7 @@ import numpy as np
 
 
 def complexity_simulate(duration=10, sampling_rate=1000, method="ornstein", hurst_exponent=0.5, **kwargs):
-    """
-    Simulate chaotic time series.
+    """Simulate chaotic time series.
 
     Generates time series using the discrete approximation of the
     Mackey-Glass delay differential equation described by Grassberger &
@@ -14,10 +13,22 @@ def complexity_simulate(duration=10, sampling_rate=1000, method="ornstein", hurs
     ----------
     duration : int
         Desired length of duration (s).
-    sampling_rate, length : int
-        The desired sampling rate (in Hz, i.e., samples/second) or the desired
+    sampling_rate : int
+        The desired sampling rate (in Hz, i.e., samples/second).
+    duration : int
+        The desired length in samples.
     method : str
-        The method. can be 'hurst' for a (fractional) Ornstein–Uhlenbeck process or 'mackeyglass' to use the Mackey-Glass equation.
+        The method. can be 'hurst' for a (fractional) Ornstein–Uhlenbeck process or 'mackeyglass' to
+        use the Mackey-Glass equation.
+    hurst_exponent : float
+        Defaults to 0.5.
+    **kwargs : optional
+        Other arguments.
+
+    Returns
+    -------
+    array
+        Simulated complexity time series.
 
     Examples
     ------------
@@ -49,9 +60,8 @@ def complexity_simulate(duration=10, sampling_rate=1000, method="ornstein", hurs
 def _complexity_simulate_mackeyglass(
     duration=10, sampling_rate=1000, x0=None, a=0.2, b=0.1, c=10.0, n=1000, discard=250
 ):
-    """
-    Generate time series using the Mackey-Glass equation. Generates time series using the discrete approximation of the
-    Mackey-Glass delay differential equation described by Grassberger & Procaccia (1983).
+    """Generate time series using the Mackey-Glass equation. Generates time series using the discrete approximation of
+    the Mackey-Glass delay differential equation described by Grassberger & Procaccia (1983).
 
     Taken from nolitsa (https://github.com/manu-mannattil/nolitsa/blob/master/nolitsa/data.py#L223).
 
@@ -59,28 +69,29 @@ def _complexity_simulate_mackeyglass(
     ----------
     duration : int
         Duration of the time series to be generated.
-    sampling_rate : float, optional (default = 0.46)
-        Sampling step of the time series.  It is useful to pick
-        something between tau/100 and tau/10, with tau/sampling_rate being
-        a factor of n.  This will make sure that there are only whole
-        number indices.
-    x0 : array, optional (default = random)
-        Initial condition for the discrete map.  Should be of length n.
-    a : float, optional (default = 0.2)
-        Constant a in the Mackey-Glass equation.
-    b : float, optional (default = 0.1)
-        Constant b in the Mackey-Glass equation.
-    c : float, optional (default = 10.0)
-        Constant c in the Mackey-Glass equation.
-    tau : float, optional (default = 23.0)
-        Time delay in the Mackey-Glass equation.
-    n : int, optional (default = 1000)
-        The number of discrete steps into which the interval between
-        t and t + tau should be divided. This results in a time
-        step of tau/n and an n + 1 dimensional map.
-    discard : int, optional (default = 250)
-        Number of n-steps to discard in order to eliminate transients.
-        A total of n*discard steps will be discarded.
+    sampling_rate : float
+        Sampling step of the time series.  It is useful to pick something between tau/100 and tau/10,
+        with tau/sampling_rate being a factor of n.  This will make sure that there are only whole
+        number indices. Defaults to 1000.
+    x0 : array
+        Initial condition for the discrete map. Should be of length n. Defaults to None.
+    a : float
+        Constant a in the Mackey-Glass equation. Defaults to 0.2.
+    b : float
+        Constant b in the Mackey-Glass equation. Defaults to 0.1.
+    c : float
+        Constant c in the Mackey-Glass equation. Defaults to 10.0
+    n : int
+        The number of discrete steps into which the interval between t and t + tau should be divided.
+        This results in a time step of tau/n and an n + 1 dimensional map. Defaults to 1000.
+    discard : int
+        Number of n-steps to discard in order to eliminate transients. A total of n*discard steps will
+        be discarded. Defaults to 250.
+
+    Returns
+    -------
+    array
+        Simulated complexity time series.
 
     """
     length = duration * sampling_rate
@@ -103,15 +114,25 @@ def _complexity_simulate_mackeyglass(
 
 
 def _complexity_simulate_ornstein(duration=10, sampling_rate=1000, theta=0.3, sigma=0.1, hurst_exponent=0.7):
-    """
-    This is based on https://github.com/LRydin/MFDFA.
+    """This is based on https://github.com/LRydin/MFDFA.
 
     Parameters
     ----------
+    duration : int
+        The desired length in samples.
+    sampling_rate : int
+        The desired sampling rate (in Hz, i.e., samples/second). Defaults to 1000Hz.
     theta : float
-        Drift.
+        Drift. Defaults to 0.3.
     sigma : float
-        Diffusion.
+        Diffusion. Defaults to 0.1.
+    hurst_exponent : float
+        Defaults to 0.7.
+
+    Returns
+    -------
+    array
+        Simulated complexity time series.
 
     """
     # Time array
@@ -130,16 +151,13 @@ def _complexity_simulate_ornstein(duration=10, sampling_rate=1000, theta=0.3, si
 
 
 def _complexity_simulate_fractionalnoise(size=1000, hurst_exponent=0.5):
-    """
-    This is based on https://github.com/LRydin/MFDFA/blob/master/MFDFA/fgn.py and the work of Christopher Flynn fbm in
-    https://github.com/crflynn/fbm and Davies, Robert B., and D. S. Harte. 'Tests for Hurst effect.' Biometrika 74, no.
-    1 (1987): 95-101.
+    """This is based on https://github.com/LRydin/MFDFA/blob/master/MFDFA/fgn.py and the work of Christopher Flynn fbm
+    in https://github.com/crflynn/fbm and Davies, Robert B., and D. S. Harte. 'Tests for Hurst effect.' Biometrika 74,
+    no.1 (1987): 95-101.
 
-    Generates fractional Gaussian noise with a Hurst index H in (0,1). If
-    H = 1/2 this is simply Gaussian noise.
-    The current method employed is the Davies–Harte method, which fails for
-    H ≈ 0. A Cholesky decomposition method and the Hosking’s method will be
-    implemented in later versions.
+    Generates fractional Gaussian noise with a Hurst index H in (0,1). If H = 1/2 this is simply Gaussian
+    noise. The current method employed is the Davies–Harte method, which fails for H ≈ 0. A Cholesky
+    decomposition method and the Hosking’s method will be implemented in later versions.
 
     Parameters
     ----------
@@ -148,6 +166,11 @@ def _complexity_simulate_fractionalnoise(size=1000, hurst_exponent=0.5):
     hurst_exponent : float
         Hurst exponent H in (0,1).
 
+    Returns
+    -------
+    array
+        Simulated complexity time series.
+
     """
     # Sanity checks
     assert isinstance(size, int), "Size must be an integer number"
