@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 import matplotlib.pyplot as plt
 import numpy as np
-import pandas as pd
 
 from .entropy_sample import entropy_sample
 from .utils import _get_coarsegrained, _get_coarsegrained_rolling, _get_r, _get_scale, _phi, _phi_divide
@@ -10,23 +9,33 @@ from .utils import _get_coarsegrained, _get_coarsegrained_rolling, _get_r, _get_
 def entropy_multiscale(
     signal, scale="default", dimension=2, r="default", composite=False, refined=False, fuzzy=False, show=False, **kwargs
 ):
-    """
-    Multiscale entropy (MSE) and its Composite (CMSE), Refined (RCMSE) or fuzzy version.
+    """Multiscale entropy (MSE) and its Composite (CMSE), Refined (RCMSE) or fuzzy version.
 
-    Python implementations of the multiscale entropy (MSE), the composite multiscale entropy (CMSE), the refined composite multiscale entropy (RCMSE) or their fuzzy version (FuzzyMSE, FuzzyCMSE or FuzzyRCMSE).
+    Python implementations of the multiscale entropy (MSE), the composite multiscale entropy (CMSE),
+    the refined composite multiscale entropy (RCMSE) or their fuzzy version (FuzzyMSE, FuzzyCMSE or
+    FuzzyRCMSE).
 
-    This function can be called either via ``entropy_multiscale()`` or ``complexity_mse()``. Moreover, variants can be directly accessed via ``complexity_cmse()``, `complexity_rcmse()``, ``complexity_fuzzymse()`` and ``complexity_fuzzyrcmse()``.
+    This function can be called either via ``entropy_multiscale()`` or ``complexity_mse()``. Moreover,
+    variants can be directly accessed via ``complexity_cmse()``, `complexity_rcmse()``,
+    ``complexity_fuzzymse()`` and ``complexity_fuzzyrcmse()``.
 
     Parameters
     ----------
-    signal : list, array or Series
+    signal : list or array or Series
         The signal (i.e., a time series) in the form of a vector of values.
-    scale : str, int or list
-        A list of scale factors used for coarse graining the time series. If 'default', will use ``range(len(signal) / (dimension + 10))`` (see discussion `here <https://github.com/neuropsychology/NeuroKit/issues/75#issuecomment-583884426>`_). If 'max', will use all scales until half the length of the signal. If an integer, will create a range until the specified int.
+    scale : str or int or list
+        A list of scale factors used for coarse graining the time series. If 'default', will use
+        ``range(len(signal) / (dimension + 10))`` (see discussion
+        `here <https://github.com/neuropsychology/NeuroKit/issues/75#issuecomment-583884426>`_).
+        If 'max', will use all scales until half the length of the signal. If an integer, will create
+        a range until the specified int.
     dimension : int
-        Embedding dimension (often denoted 'm' or 'd', sometimes referred to as 'order'). Typically 2 or 3. It corresponds to the number of compared runs of lagged data. If 2, the embedding returns an array with two columns corresponding to the original signal and its delayed (by Tau) version.
+        Embedding dimension (often denoted 'm' or 'd', sometimes referred to as 'order'). Typically
+        2 or 3. It corresponds to the number of compared runs of lagged data. If 2, the embedding returns
+        an array with two columns corresponding to the original signal and its delayed (by Tau) version.
     r : float
-        Tolerance (i.e., filtering level - max absolute difference between segments). If 'default', will be set to 0.2 times the standard deviation of the signal (for dimension = 2).
+        Tolerance (i.e., filtering level - max absolute difference between segments). If 'default',
+        will be set to 0.2 times the standard deviation of the signal (for dimension = 2).
     composite : bool
         Returns the composite multiscale entropy (CMSE), more accurate than MSE.
     refined : bool
@@ -35,13 +44,16 @@ def entropy_multiscale(
         Returns the fuzzy (composite) multiscale entropy (FuzzyMSE, FuzzyCMSE or FuzzyRCMSE).
     show : bool
         Show the entropy values for each scale factor.
-
+    **kwargs
+        Optional arguments.
 
 
     Returns
     ----------
     float
-        The point-estimate of multiscale entropy (MSE) as a float value corresponding to the area under the MSE values curvee, which is essentially the sum of sample entropy values over the range of scale factors.
+        The point-estimate of multiscale entropy (MSE) as a float value corresponding to the area under
+        the MSE values curvee, which is essentially the sum of sample entropy values over the range of
+        scale factors.
 
     See Also
     --------
@@ -63,15 +75,25 @@ def entropy_multiscale(
     References
     -----------
     - `pyEntropy` <https://github.com/nikdon/pyEntropy>`_
-    - Richman, J. S., & Moorman, J. R. (2000). Physiological time-series analysis using approximate entropy
-        and sample entropy. American Journal of Physiology-Heart and Circulatory Physiology, 278(6), H2039-H2049.
-    - Costa, M., Goldberger, A. L., & Peng, C. K. (2005). Multiscale entropy analysis of biological signals.
-        Physical review E, 71(2), 021906.
-    - Gow, B. J., Peng, C. K., Wayne, P. M., & Ahn, A. C. (2015). Multiscale entropy analysis of center-of-pressure
-        dynamics in human postural control: methodological considerations. Entropy, 17(12), 7926-7947.
+
+    - Richman, J. S., & Moorman, J. R. (2000). Physiological time-series analysis using approximate
+      entropy and sample entropy. American Journal of Physiology-Heart and Circulatory Physiology,
+      278(6), H2039-H2049.
+
+    - Costa, M., Goldberger, A. L., & Peng, C. K. (2005). Multiscale entropy analysis of biological
+      signals. Physical review E, 71(2), 021906.
+
+    - Gow, B. J., Peng, C. K., Wayne, P. M., & Ahn, A. C. (2015). Multiscale entropy analysis of
+      center-of-pressure dynamics in human postural control: methodological considerations. Entropy,
+      17(12), 7926-7947.
+
     - Norris, P. R., Anderson, S. M., Jenkins, J. M., Williams, A. E., & Morris Jr, J. A. (2008).
-        Heart rate multiscale entropy at three hours predicts hospital mortality in 3,154 trauma patients. Shock, 30(1), 17-22.
-    - Liu, Q., Wei, Q., Fan, S. Z., Lu, C. W., Lin, T. Y., Abbod, M. F., & Shieh, J. S. (2012). Adaptive computation of multiscale entropy and its application in EEG signals for monitoring depth of anesthesia during surgery. Entropy, 14(6), 978-992.
+      Heart rate multiscale entropy at three hours predicts hospital mortality in 3,154 trauma patients.
+      Shock, 30(1), 17-22.
+
+    - Liu, Q., Wei, Q., Fan, S. Z., Lu, C. W., Lin, T. Y., Abbod, M. F., & Shieh, J. S. (2012). Adaptive
+      computation of multiscale entropy and its application in EEG signals for monitoring depth of
+      anesthesia during surgery. Entropy, 14(6), 978-992.
 
     """
     return _entropy_multiscale(
@@ -103,15 +125,15 @@ def _entropy_multiscale(
 
         # Regular MSE
         if refined is False and composite is False:
-            mse[i] = _entropy_multiscale_mse(signal, tau, dimension, r, fuzzy)
+            mse[i] = _entropy_multiscale_mse(signal, tau, dimension, r, fuzzy, **kwargs)
 
         # Composite MSE
         elif refined is False and composite is True:
-            mse[i] = _entropy_multiscale_cmse(signal, tau, dimension, r, fuzzy)
+            mse[i] = _entropy_multiscale_cmse(signal, tau, dimension, r, fuzzy, **kwargs)
 
         # Refined Composite MSE
         else:
-            mse[i] = _entropy_multiscale_rcmse(signal, tau, dimension, r, fuzzy)
+            mse[i] = _entropy_multiscale_rcmse(signal, tau, dimension, r, fuzzy, **kwargs)
 
     if show is True:
         plt.plot(scale_factors, mse)
