@@ -5,15 +5,16 @@ import pandas as pd
 
 
 def data(dataset="bio_eventrelated_100hz"):
-    """
-    Example datasets.
+    """Download example datasets.
 
-    Download and load available `example datasets <https://github.com/neuropsychology/NeuroKit/tree/master/data#datasets>`_. Note that an internet connexion is necessary.
+    Download and load available `example datasets <https://github.com/neuropsychology/NeuroKit/tree/master/data#datasets>`_.
+    Note that an internet connexion is necessary.
 
     Parameters
     ----------
     dataset : str
-        The name of the dataset. The list and description is available `here <https://neurokit2.readthedocs.io/en/master/datasets.html#>`_.
+        The name of the dataset. The list and description is
+        available `here <https://neurokit2.readthedocs.io/en/master/datasets.html#>`_.
 
     Returns
     -------
@@ -36,14 +37,14 @@ def data(dataset="bio_eventrelated_100hz"):
 
     # Specific case
     if dataset.lower() in ["eeg", "eeg.txt"]:
-        data = pd.read_csv(path + "eeg.txt")
-        return data.values[:, 0]
+        df = pd.read_csv(path + "eeg.txt")
+        return df.values[:, 0]
 
     # General case
-    file, ext = os.path.splitext(dataset)
+    file, ext = os.path.splitext(dataset)  # pylint: disable=unused-variable
     if ext == "":
-        data = pd.read_csv(path + dataset + ".csv")
+        df = pd.read_csv(path + dataset + ".csv")
     else:
-        data = pd.read_csv(path + dataset)
+        df = pd.read_csv(path + dataset)
 
-    return data
+    return df
