@@ -1,6 +1,4 @@
-"""
-Submodule for NeuroKit.
-"""
+"""Submodule for NeuroKit."""
 
 # Aliases
 from ..signal import signal_rate as ecg_rate
