@@ -14,45 +14,51 @@ from .ecg_segment import ecg_segment
 def ecg_delineate(
     ecg_cleaned, rpeaks=None, sampling_rate=1000, method="peak", show=False, show_type="peaks", check=False
 ):
-    """
-    Delineate QRS complex.
+    """Delineate QRS complex.
 
     Function to delineate the QRS complex.
 
-    - **Cardiac Cycle**: A typical ECG heartbeat consists of a P wave, a QRS complex and a T wave.The P wave represents the wave of depolarization that spreads from the SA-node throughout the atria. The QRS complex reflects the rapid depolarization of the right and left ventricles. Since the ventricles are the largest part of the heart, in terms of mass, the QRS complex usually has a much larger amplitude than the P-wave. The T wave represents the ventricular repolarization of the ventricles. On rare occasions, a U wave can be seen following the T wave. The U wave is believed to be related to the last remnants of ventricular repolarization.
+    - **Cardiac Cycle**: A typical ECG heartbeat consists of a P wave, a QRS complex and a T wave.
+      The P wave represents the wave of depolarization that spreads from the SA-node throughout the atria.
+      The QRS complex reflects the rapid depolarization of the right and left ventricles. Since the
+      ventricles are the largest part of the heart, in terms of mass, the QRS complex usually has a much
+      larger amplitude than the P-wave. The T wave represents the ventricular repolarization of the
+      ventricles.On rare occasions, a U wave can be seen following the T wave. The U wave is believed
+      to be related to the last remnants of ventricular repolarization.
 
     Parameters
     ----------
-    ecg_cleaned : list, array or Series
+    ecg_cleaned : list or array or Series
         The cleaned ECG channel as returned by `ecg_clean()`.
-    rpeaks : list, array or Series
-        The samples at which R-peaks occur. Accessible with the key "ECG_R_Peaks" in the info dictionary returned by `ecg_findpeaks()`.
+    rpeaks : list or array or Series
+        The samples at which R-peaks occur. Accessible with the key "ECG_R_Peaks" in the info dictionary
+        returned by `ecg_findpeaks()`.
     sampling_rate : int
         The sampling frequency of `ecg_signal` (in Hz, i.e., samples/second).
         Defaults to 500.
     method : str
-        Can be one of 'peak' (default) for a peak-based method, 'cwt' for continuous wavelet transform or 'dwt' for discrete wavelet transform.
+        Can be one of 'peak' (default) for a peak-based method, 'cwt' for continuous wavelet transform
+        or 'dwt' for discrete wavelet transform.
     show : bool
         If True, will return a plot to visualizing the delineated waves
         information.
     show_type: str
-        The type of delineated waves information showed in the plot
+        The type of delineated waves information showed in the plot.
+    check : bool
+        Defaults to False.
 
     Returns
     -------
     waves : dict
         A dictionary containing additional information.
-        For derivative method, the dictionary contains the
-        samples at which P-peaks, Q-peaks, S-peaks, T-peaks, P-onsets and T-
-        offsets occur, accessible with the key "ECG_P_Peaks", "ECG_Q_Peaks",
-        "ECG_S_Peaks", "ECG_T_Peaks", "ECG_P_Onsets", "ECG_T_Offsets"
-        respectively.
+        For derivative method, the dictionary contains the samples at which P-peaks, Q-peaks, S-peaks,
+        T-peaks, P-onsets and T-offsets occur, accessible with the key "ECG_P_Peaks", "ECG_Q_Peaks",
+        "ECG_S_Peaks", "ECG_T_Peaks", "ECG_P_Onsets", "ECG_T_Offsets" respectively.
 
-        For wavelet methods, the dictionary contains the samples at
-        which P-peaks, T-peaks, P-onsets, P-offsets, T-onsets, T-offsets, QRS-
-        onsets and QRS-offsets occur, accessible with the key "ECG_P_Peaks",
-        "ECG_T_Peaks", "ECG_P_Onsets", "ECG_P_Offsets", "ECG_T_Onsets",
-        "ECG_T_Offsets", "ECG_R_Onsets", "ECG_R_Offsets" respectively.
+        For wavelet methods, the dictionary contains the samples at which P-peaks, T-peaks, P-onsets,
+        P-offsets, T-onsets, T-offsets, QRS-onsets and QRS-offsets occur, accessible with the key
+        "ECG_P_Peaks", "ECG_T_Peaks", "ECG_P_Onsets", "ECG_P_Offsets", "ECG_T_Onsets", "ECG_T_Offsets",
+        "ECG_R_Onsets", "ECG_R_Offsets" respectively.
 
     signals : DataFrame
         A DataFrame of same length as the input signal in which occurences of
@@ -77,7 +83,9 @@ def ecg_delineate(
 
     References
     --------------
-    - Martínez, J. P., Almeida, R., Olmos, S., Rocha, A. P., & Laguna, P. (2004). A wavelet-based ECG delineator: evaluation on standard databases. IEEE Transactions on biomedical engineering, 51(4), 570-581.
+    - Martínez, J. P., Almeida, R., Olmos, S., Rocha, A. P., & Laguna, P. (2004). A wavelet-based ECG
+      delineator: evaluation on standard databases. IEEE Transactions on biomedical engineering,
+      51(4), 570-581.
 
     """
     # Sanitize input for ecg_cleaned
@@ -86,7 +94,8 @@ def ecg_delineate(
         if cols:
             ecg_cleaned = ecg_cleaned[cols[0]].values
         else:
-            raise ValueError("NeuroKit error: ecg_delineate(): Wrong input, we couldn't extract cleaned signal.")
+            raise ValueError("NeuroKit error: ecg_delineate(): Wrong input, we couldn't extract" "cleaned signal.")
+
     elif isinstance(ecg_cleaned, dict):
         for i in ecg_cleaned:
             cols = [col for col in ecg_cleaned[i].columns if "ECG_Clean" in col]
@@ -95,7 +104,8 @@ def ecg_delineate(
                 ecg_cleaned = signals[cols[0]].values
 
             else:
-                raise ValueError("NeuroKit error: ecg_delineate(): Wrong input, we couldn't extract cleaned signal.")
+                raise ValueError("NeuroKit error: ecg_delineate(): Wrong input, we couldn't extract" "cleaned signal.")
+
     # Sanitize input for rpeaks
     if rpeaks is None:
         _, rpeaks = ecg_peaks(ecg_cleaned, sampling_rate=sampling_rate)
@@ -113,7 +123,7 @@ def ecg_delineate(
         waves = _dwt_ecg_delineator(ecg_cleaned, rpeaks, sampling_rate=sampling_rate)
 
     else:
-        raise ValueError("NeuroKit error: ecg_delineate(): 'method' should be  one of 'peak', 'cwt' or 'dwt'.")
+        raise ValueError("NeuroKit error: ecg_delineate(): 'method' should be  one of 'peak'," "'cwt' or 'dwt'.")
 
     # Remove NaN in Peaks, Onsets, and Offsets
     waves_noNA = waves.copy()
@@ -138,8 +148,7 @@ def ecg_delineate(
 # WAVELET METHOD (DWT)
 # =============================================================================
 def _dwt_resample_points(peaks, sampling_rate, desired_sampling_rate):
-    """
-    Resample given points to a different sampling rate.
+    """Resample given points to a different sampling rate.
     """
     peaks_resample = np.array(peaks) * desired_sampling_rate / sampling_rate
     peaks_resample = [np.nan if np.isnan(x) else int(x) for x in peaks_resample.tolist()]
@@ -147,16 +156,24 @@ def _dwt_resample_points(peaks, sampling_rate, desired_sampling_rate):
 
 
 def _dwt_ecg_delineator(ecg, rpeaks, sampling_rate, analysis_sampling_rate=2000):
-    """
-    Delinate ecg signal using discrete wavelet transforms.
+    """Delinate ecg signal using discrete wavelet transforms.
 
-    Args:
-     ecg: Signal.
-     sampling_rate: Sampling rate of input signal.
-     analysis_sampling_rate: Sampling rate for analysis.
+    Parameters
+    ----------
+    ecg : list or array or Series
+        The cleaned ECG channel as returned by `ecg_clean()`.
+    rpeaks : list or array or Series
+        The samples at which R-peaks occur. Accessible with the key "ECG_R_Peaks" in the info dictionary
+        returned by `ecg_findpeaks()`.
+    sampling_rate : int
+        The sampling frequency of `ecg_signal` (in Hz, i.e., samples/second).
+    analysis_sampling_rate : int
+        The sampling frequency for analysis (in Hz, i.e., samples/second).
 
-    Returns:
-     Dictionary of the points.
+    Returns
+    --------
+    dict
+        Dictionary of the points.
 
     """
     ecg = signal_resample(ecg, sampling_rate=sampling_rate, desired_sampling_rate=analysis_sampling_rate)
@@ -171,17 +188,13 @@ def _dwt_ecg_delineator(ecg, rpeaks, sampling_rate, analysis_sampling_rate=2000)
     # plt.show()
     rpeaks_resampled = _dwt_resample_points(rpeaks, sampling_rate, analysis_sampling_rate)
 
-    tpeaks, ppeaks = _dwt_delineate_tp_peaks(
-        ecg, rpeaks_resampled, dwtmatr, sampling_rate=analysis_sampling_rate, debug=False
-    )
+    tpeaks, ppeaks = _dwt_delineate_tp_peaks(ecg, rpeaks_resampled, dwtmatr, sampling_rate=analysis_sampling_rate)
     qrs_onsets, qrs_offsets = _dwt_delineate_qrs_bounds(
-        ecg, rpeaks_resampled, dwtmatr, ppeaks, tpeaks, sampling_rate=analysis_sampling_rate, debug=False
-    )
-    ponsets, poffsets = _dwt_delineate_tp_onsets_offsets(
-        ecg, ppeaks, dwtmatr, sampling_rate=analysis_sampling_rate, debug=False
+        rpeaks_resampled, dwtmatr, ppeaks, tpeaks, sampling_rate=analysis_sampling_rate
     )
+    ponsets, poffsets = _dwt_delineate_tp_onsets_offsets(ppeaks, dwtmatr, sampling_rate=analysis_sampling_rate)
     tonsets, toffsets = _dwt_delineate_tp_onsets_offsets(
-        ecg, tpeaks, dwtmatr, sampling_rate=analysis_sampling_rate, debug=False, onset_weight=0.6, duration=0.6
+        tpeaks, dwtmatr, sampling_rate=analysis_sampling_rate, onset_weight=0.6, duration=0.6
     )
 
     return dict(
@@ -205,8 +218,6 @@ def _dwt_delineate_tp_peaks(
     rpeaks,
     dwtmatr,
     sampling_rate=250,
-    debug=False,
-    dwt_delay=0.0,
     qrs_width=0.13,
     p2r_duration=0.2,
     rt_duration=0.25,
@@ -234,8 +245,8 @@ def _dwt_delineate_tp_peaks(
             continue
 
         ecg_local = ecg[srch_idx_start:srch_idx_end]
-        peaks, peak_heights = scipy.signal.find_peaks(np.abs(dwt_local), height=height)
-        peaks = list(filter(lambda p: np.abs(dwt_local[p]) > 0.025 * max(dwt_local), peaks))
+        peaks, __ = scipy.signal.find_peaks(np.abs(dwt_local), height=height)
+        peaks = list(filter(lambda p: np.abs(dwt_local[p]) > 0.025 * max(dwt_local), peaks))  # pylint: disable=W0640
         if dwt_local[0] > 0:  # just append
             peaks = [0] + peaks
 
@@ -243,7 +254,7 @@ def _dwt_delineate_tp_peaks(
         candidate_peaks = []
         candidate_peaks_scores = []
         for idx_peak, idx_peak_nxt in zip(peaks[:-1], peaks[1:]):
-            correct_sign = dwt_local[idx_peak] > 0 and dwt_local[idx_peak_nxt] < 0
+            correct_sign = dwt_local[idx_peak] > 0 and dwt_local[idx_peak_nxt] < 0  # pylint: disable=R1716
             if correct_sign:
                 idx_zero = signal_zerocrossings(dwt_local[idx_peak:idx_peak_nxt])[0] + idx_peak
                 # This is the score assigned to each peak. The peak with the highest score will be
@@ -275,7 +286,7 @@ def _dwt_delineate_tp_peaks(
             continue
 
         ecg_local = ecg[srch_idx_start:srch_idx_end]
-        peaks, peak_heights = scipy.signal.find_peaks(np.abs(dwt_local), height=height)
+        peaks, __ = scipy.signal.find_peaks(np.abs(dwt_local), height=height)
         peaks = list(filter(lambda p: np.abs(dwt_local[p]) > 0.025 * max(dwt_local), peaks))
         if dwt_local[0] > 0:  # just append
             peaks = [0] + peaks
@@ -284,7 +295,7 @@ def _dwt_delineate_tp_peaks(
         candidate_peaks = []
         candidate_peaks_scores = []
         for idx_peak, idx_peak_nxt in zip(peaks[:-1], peaks[1:]):
-            correct_sign = dwt_local[idx_peak] > 0 and dwt_local[idx_peak_nxt] < 0
+            correct_sign = dwt_local[idx_peak] > 0 and dwt_local[idx_peak_nxt] < 0  # pylint: disable=R1716
             if correct_sign:
                 idx_zero = signal_zerocrossings(dwt_local[idx_peak:idx_peak_nxt])[0] + idx_peak
                 # This is the score assigned to each peak. The peak with the highest score will be
@@ -305,11 +316,9 @@ def _dwt_delineate_tp_peaks(
 
 
 def _dwt_delineate_tp_onsets_offsets(
-    ecg,
     peaks,
     dwtmatr,
     sampling_rate=250,
-    debug=False,
     duration=0.3,
     duration_offset=0.3,
     onset_weight=0.4,
@@ -320,7 +329,7 @@ def _dwt_delineate_tp_onsets_offsets(
     degree = _dwt_compensate_degree(sampling_rate)
     onsets = []
     offsets = []
-    for i in range(len(peaks)):
+    for i in range(len(peaks)):  # pylint: disable=C0200
         if np.isnan(peaks[i]):
             onsets.append(np.nan)
             offsets.append(np.nan)
@@ -333,7 +342,7 @@ def _dwt_delineate_tp_onsets_offsets(
             offsets.append(np.nan)
             continue
         dwt_local = dwtmatr[degree_onset + degree, srch_idx_start:srch_idx_end]
-        onset_slope_peaks, onset_slope_data = scipy.signal.find_peaks(dwt_local)
+        onset_slope_peaks, __ = scipy.signal.find_peaks(dwt_local)
         try:
             epsilon_onset = onset_weight * dwt_local[onset_slope_peaks[-1]]
             candidate_onsets = np.where(dwt_local[: onset_slope_peaks[-1]] < epsilon_onset)[0]
@@ -353,7 +362,7 @@ def _dwt_delineate_tp_onsets_offsets(
             offsets.append(np.nan)
             continue
         dwt_local = dwtmatr[degree_offset + degree, srch_idx_start:srch_idx_end]
-        offset_slope_peaks, offset_slope_data = scipy.signal.find_peaks(-dwt_local)
+        offset_slope_peaks, __ = scipy.signal.find_peaks(-dwt_local)
         try:
             epsilon_offset = -offset_weight * dwt_local[offset_slope_peaks[0]]
             candidate_offsets = (
@@ -371,10 +380,10 @@ def _dwt_delineate_tp_onsets_offsets(
     return onsets, offsets
 
 
-def _dwt_delineate_qrs_bounds(ecg, rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250, debug=False):
+def _dwt_delineate_qrs_bounds(rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250):
     degree = int(np.log2(sampling_rate / 250))
     onsets = []
-    for i in range(len(rpeaks)):
+    for i in range(len(rpeaks)):  # pylint: disable=C0200
         # look for onsets
         srch_idx_start = ppeaks[i]
         srch_idx_end = rpeaks[i]
@@ -382,7 +391,7 @@ def _dwt_delineate_qrs_bounds(ecg, rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rat
             onsets.append(np.nan)
             continue
         dwt_local = dwtmatr[2 + degree, srch_idx_start:srch_idx_end]
-        onset_slope_peaks, onset_slope_data = scipy.signal.find_peaks(-dwt_local)
+        onset_slope_peaks, __ = scipy.signal.find_peaks(-dwt_local)
         epsilon_onset = 0.5 * -dwt_local[onset_slope_peaks[-1]]
         candidate_onsets = np.where(-dwt_local[: onset_slope_peaks[-1]] < epsilon_onset)[0]
         onsets.append(candidate_onsets[-1] + srch_idx_start)
@@ -394,7 +403,7 @@ def _dwt_delineate_qrs_bounds(ecg, rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rat
         # plt.show()
 
     offsets = []
-    for i in range(len(rpeaks)):
+    for i in range(len(rpeaks)):  # pylint: disable=C0200
         # look for offsets
         srch_idx_start = rpeaks[i]
         srch_idx_end = tpeaks[i]
@@ -402,7 +411,7 @@ def _dwt_delineate_qrs_bounds(ecg, rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rat
             offsets.append(np.nan)
             continue
         dwt_local = dwtmatr[2 + degree, srch_idx_start:srch_idx_end]
-        onset_slope_peaks, onset_slope_data = scipy.signal.find_peaks(dwt_local)
+        onset_slope_peaks, __ = scipy.signal.find_peaks(dwt_local)
         if len(onset_slope_peaks) == 0:
             offsets.append(np.nan)
             continue
@@ -418,8 +427,7 @@ def _dwt_delineate_qrs_bounds(ecg, rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rat
 
 
 def _dwt_compute_multiscales(ecg: np.ndarray, max_degree):
-    """
-    Return multiscales wavelet transforms.
+    """Return multiscales wavelet transforms.
     """
 
     def _apply_H_filter(signal_i, power=0):
@@ -496,7 +504,7 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
         )
     # first derivative of the Gaissian signal
     scales = np.array([1, 2, 4, 8, 16])
-    cwtmatr, freqs = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
+    cwtmatr, __ = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
 
     half_wave_width = int(0.1 * sampling_rate)  # NEED TO CHECK
     onsets = []
@@ -579,7 +587,7 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
     return onsets, offsets
 
 
-def _peaks_delineator(ecg, rpeaks, cleaning=False, sampling_rate=1000):
+def _peaks_delineator(ecg, rpeaks, sampling_rate=1000):
     # Try loading pywt
     try:
         import pywt
@@ -590,14 +598,12 @@ def _peaks_delineator(ecg, rpeaks, cleaning=False, sampling_rate=1000):
         )
     # first derivative of the Gaissian signal
     scales = np.array([1, 2, 4, 8, 16])
-    cwtmatr, freqs = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
+    cwtmatr, __ = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
 
     qrs_duration = 0.1
 
     search_boundary = int(0.9 * qrs_duration * sampling_rate / 2)
     significant_peaks_groups = []
-    tppeaks_pairs = []
-    tppeaks = []
     for i in range(len(rpeaks) - 1):
         # search for T peaks and P peaks from R peaks
         start = rpeaks[i] + search_boundary
@@ -634,12 +640,12 @@ def _find_tppeaks(ecg, keep_tp, sampling_rate=1000):
         )
     # first derivative of the Gaissian signal
     scales = np.array([1, 2, 4, 8, 16])
-    cwtmatr, freqs = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
+    cwtmatr, __ = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
     max_search_duration = 0.05
     tppeaks = []
     for index_cur, index_next in zip(keep_tp[:-1], keep_tp[1:]):
         # limit 1
-        correct_sign = cwtmatr[4, :][index_cur] < 0 and cwtmatr[4, :][index_next] > 0
+        correct_sign = cwtmatr[4, :][index_cur] < 0 and cwtmatr[4, :][index_next] > 0  # pylint: disable=R1716
         #    near = (index_next - index_cur) < max_wv_peak_dist #limit 2
         #    if near and correct_sign:
         if correct_sign:
@@ -682,7 +688,7 @@ def _ecg_delineator_peak(ecg, rpeaks=None, sampling_rate=1000):
         P_list.append(P_index)
 
         # S wave
-        S_index, S = _ecg_delineator_peak_S(rpeak, heartbeat, R)
+        S_index, S = _ecg_delineator_peak_S(rpeak, heartbeat)
         S_list.append(S_index)
 
         # T wave
@@ -733,7 +739,7 @@ def _ecg_delineator_peak_P(rpeak, heartbeat, R, Q):
     return rpeak - from_R, P
 
 
-def _ecg_delineator_peak_S(rpeak, heartbeat, R):
+def _ecg_delineator_peak_S(rpeak, heartbeat):
     segment = heartbeat[0:]  # Select right hand side
     S = signal_findpeaks(-segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()))
 
@@ -802,8 +808,7 @@ def _ecg_delineator_peak_T_offset(rpeak, heartbeat, R, T):
 
 def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_type="all", sampling_rate=1000):
 
-    """
-    #    Examples.
+    """#    Examples.
 
 #    --------
 #    >>> import neurokit2 as nk
@@ -811,7 +816,8 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
 #    >>> import pandas as pd
 #    >>> import matplotlib.pyplot as plt
 #
-#    >>> ecg_signal = np.array(pd.read_csv("https://raw.githubusercontent.com/neuropsychology/NeuroKit/dev/data/ecg_1000hz.csv"))[:, 1]
+#    >>> ecg_signal = np.array(pd.read_csv(
+#    "https://raw.githubusercontent.com/neuropsychology/NeuroKit/dev/data/ecg_1000hz.csv"))[:, 1]
 #
 #    >>> # Extract R-peaks locations
 #    >>> _, rpeaks = nk.ecg_peaks(ecg_signal, sampling_rate=1000)
@@ -820,19 +826,24 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
 #    >>> signals, waves = nk.ecg_delineate(ecg_signal, rpeaks, sampling_rate=1000)
 #
 #    >>> # Plot the ECG signal with markings on ECG peaks
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals, signal_features_type='peaks', sampling_rate=1000)
+#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+#                            signal_features_type='peaks', sampling_rate=1000)
 #
 #    >>> # Plot the ECG signal with markings on boundaries of R peaks
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals, signal_features_type='bound_R', sampling_rate=1000)
+#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+#                            signal_features_type='bound_R', sampling_rate=1000)
 #
 #    >>> # Plot the ECG signal with markings on boundaries of P peaks
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals, signal_features_type='bound_P', sampling_rate=1000)
+#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+#                            signal_features_type='bound_P', sampling_rate=1000)
 #
 #    >>> # Plot the ECG signal with markings on boundaries of T peaks
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals, signal_features_type='bound_T', sampling_rate=1000)
+#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+#                            signal_features_type='bound_T', sampling_rate=1000)
 #
 #    >>> # Plot the ECG signal with markings on all peaks and boundaries
-#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals, signal_features_type='all', sampling_rate=1000)
+#    >>> _ecg_delineate_plot(ecg_signal, rpeaks=rpeaks, signals=signals,
+#                            signal_features_type='all', sampling_rate=1000)
 
     """
 
@@ -876,7 +887,7 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
     for label in data.Label.unique():
         epoch_data = data[data.Label == label]
         ax.plot(epoch_data.Time, epoch_data.Signal, color="grey", alpha=0.2, label="_nolegend_")
-    for i, feature_type in enumerate(features.columns.values):
+    for i, feature_type in enumerate(features.columns.values):  # pylint: disable=W0612
         event_data = data[data[feature_type] == 1.0]
         ax.scatter(event_data.Time, event_data.Signal, label=feature_type, alpha=0.5, s=200)
         ax.legend()
@@ -884,8 +895,7 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
 
 
 def _ecg_delineate_check(waves, rpeaks):
-    """
-    This function replaces the delineated features with np.nan if its standardized distance from R-peaks is more than 3.
+    """This function replaces the delineated features with np.nan if its standardized distance from R-peaks is more than 3.
     """
     df = pd.DataFrame.from_dict(waves)
     features_columns = df.columns
@@ -893,11 +903,9 @@ def _ecg_delineate_check(waves, rpeaks):
     df = pd.concat([df, pd.DataFrame({"ECG_R_Peaks": rpeaks})], axis=1)
 
     # loop through all columns to calculate the z distance
-    for column in features_columns:
+    for column in features_columns:  # pylint: disable=W0612
         df = _calculate_abs_z(df, features_columns)
 
-    distance_columns = [col for col in df.columns if "Dist" in col]
-
     # Replace with nan if distance > 3
     for col in features_columns:
         for i in range(len(df)):
@@ -911,8 +919,7 @@ def _ecg_delineate_check(waves, rpeaks):
 
 
 def _calculate_abs_z(df, columns):
-    """
-    This function helps to calculate the absolute standardized distance between R-peaks and other delineated waves
+    """This function helps to calculate the absolute standardized distance between R-peaks and other delineated waves
     features by `ecg_delineate()`
     """
     for column in columns:
