@@ -10,8 +10,7 @@ from .ecg_quality import ecg_quality
 
 
 def ecg_process(ecg_signal, sampling_rate=1000, method="neurokit"):
-    """
-    Process an ECG signal.
+    """Process an ECG signal.
 
     Convenience function that automatically processes an ECG signal.
 
@@ -28,39 +27,53 @@ def ecg_process(ecg_signal, sampling_rate=1000, method="neurokit"):
     Returns
     -------
     signals : DataFrame
-        A DataFrame of the same length as the `ecg_signal` containing the
-        following columns:
+        A DataFrame of the same length as the `ecg_signal` containing the following columns:
+
         - *"ECG_Raw"*: the raw signal.
+
         - *"ECG_Clean"*: the cleaned signal.
+
         - *"ECG_R_Peaks"*: the R-peaks marked as "1" in a list of zeros.
+
         - *"ECG_Rate"*: heart rate interpolated between R-peaks.
+
         - *"ECG_P_Peaks"*: the P-peaks marked as "1" in a list of zeros
+
         - *"ECG_Q_Peaks"*: the Q-peaks marked as "1" in a list of zeros .
+
         - *"ECG_S_Peaks"*: the S-peaks marked as "1" in a list of zeros.
+
         - *"ECG_T_Peaks"*: the T-peaks marked as "1" in a list of zeros.
+
         - *"ECG_P_Onsets"*: the P-onsets marked as "1" in a list of zeros.
+
         - *"ECG_P_Offsets"*: the P-offsets marked as "1" in a list of zeros
                             (only when method in `ecg_delineate` is wavelet).
+
         - *"ECG_T_Onsets"*: the T-onsets marked as "1" in a list of zeros
                             (only when method in `ecg_delineate` is wavelet).
+
         - *"ECG_T_Offsets"*: the T-offsets marked as "1" in a list of zeros.
+
         - *"ECG_R_Onsets"*: the R-onsets marked as "1" in a list of zeros
                             (only when method in `ecg_delineate` is wavelet).
+
         - *"ECG_R_Offsets"*: the R-offsets marked as "1" in a list of zeros
                             (only when method in `ecg_delineate` is wavelet).
+
         - *"ECG_Phase_Atrial"*: cardiac phase, marked by "1" for systole
           and "0" for diastole.
-        - *"ECG_Phase_Ventricular"*: cardiac phase, marked by "1" for systole
-          and "0" for diastole.
-          *"ECG_Atrial_PhaseCompletion"*: cardiac phase (atrial) completion,
-          expressed in percentage (from 0 to 1), representing the stage of the
-          current cardiac phase.
-          *"ECG_Ventricular_PhaseCompletion"*: cardiac phase (ventricular)
-          completion, expressed in percentage (from 0 to 1), representing the
-          stage of the current cardiac phase.
+
+        - *"ECG_Phase_Ventricular"*: cardiac phase, marked by "1" for systole and "0" for diastole.
+
+        - *"ECG_Atrial_PhaseCompletion"*: cardiac phase (atrial) completion, expressed in percentage
+          (from 0 to 1), representing the stage of the current cardiac phase.
+
+        - *"ECG_Ventricular_PhaseCompletion"*: cardiac phase (ventricular) completion, expressed in
+          percentage (from 0 to 1), representing the stage of the current cardiac phase.
     info : dict
-        A dictionary containing the samples at which the R-peaks occur,
-        accessible with the key "ECG_Peaks".
+        A dictionary containing the samples at which the R-peaks occur, accessible with the key
+        "ECG_Peaks".
 
     See Also
     --------
