@@ -1,6 +1,4 @@
-"""
-Submodule for NeuroKit.
-"""
+"""Submodule for NeuroKit."""
 
 from .eda_analyze import eda_analyze
 from .eda_autocor import eda_autocor
