@@ -10,8 +10,7 @@ from .eda_fixpeaks import eda_fixpeaks
 
 
 def eda_peaks(eda_phasic, sampling_rate=1000, method="neurokit", amplitude_min=0.1):
-    """
-    Identify Skin Conductance Responses (SCR) in Electrodermal Activity (EDA).
+    """Identify Skin Conductance Responses (SCR) in Electrodermal Activity (EDA).
 
     Identify Skin Conductance Responses (SCR) peaks in the phasic component of
     Electrodermal Activity (EDA) with different possible methods, such as:
@@ -23,7 +22,7 @@ def eda_peaks(eda_phasic, sampling_rate=1000, method="neurokit", amplitude_min=0
 
     Parameters
     ----------
-    eda_phasic : list, array or Series
+    eda_phasic : list or array or Series
         The phasic component of the EDA signal (from `eda_phasic()`).
     sampling_rate : int
         The sampling frequency of the EDA signal (in Hz, i.e., samples/second).
@@ -31,19 +30,18 @@ def eda_peaks(eda_phasic, sampling_rate=1000, method="neurokit", amplitude_min=0
         The processing pipeline to apply. Can be one of "neurokit" (default),
         "gamboa2008" or "kim2004" (the default in BioSPPy).
     amplitude_min : float
-        Only used if 'method' is 'neurokit' or 'kim2004'. Minimum threshold by which to exclude SCRs (peaks) as relative to the largest amplitude in the signal.
+        Only used if 'method' is 'neurokit' or 'kim2004'. Minimum threshold by which to exclude
+        SCRs (peaks) as relative to the largest amplitude in the signal.
 
     Returns
     -------
     info : dict
-        A dictionary containing additional information, in this case the
-        aplitude of the SCR, the samples at which the SCR onset and the
-        SCR peaks occur. Accessible with the keys "SCR_Amplitude", "SCR_Onsets",
-        and "SCR_Peaks" respectively.
+        A dictionary containing additional information, in this case the aplitude of the SCR, the samples
+        at which the SCR onset and the SCR peaks occur. Accessible with the keys "SCR_Amplitude",
+        "SCR_Onsets", and "SCR_Peaks" respectively.
     signals : DataFrame
-        A DataFrame of same length as the input signal in which occurences of
-        SCR peaks are marked as "1" in lists of zeros with the same length as
-        `eda_cleaned`. Accessible with the keys "SCR_Peaks".
+        A DataFrame of same length as the input signal in which occurences of SCR peaks are marked as
+        "1" in lists of zeros with the same length as `eda_cleaned`. Accessible with the keys "SCR_Peaks".
 
     See Also
     --------
@@ -70,19 +68,21 @@ def eda_peaks(eda_phasic, sampling_rate=1000, method="neurokit", amplitude_min=0
 
     References
     ----------
-    - Gamboa, H. (2008). Multi-modal behavioral biometrics based on hci and electrophysiology. PhD ThesisUniversidade.
-    - Kim, K. H., Bang, S. W., & Kim, S. R. (2004). Emotion recognition system using short-term monitoring of physiological signals. Medical and biological engineering and computing, 42(3), 419-427.
+    - Gamboa, H. (2008). Multi-modal behavioral biometrics based on hci and electrophysiology.
+      PhD ThesisUniversidade.
+    - Kim, K. H., Bang, S. W., & Kim, S. R. (2004). Emotion recognition system using short-term monitoring
+      of physiological signals. Medical and biological engineering and computing, 42(3), 419-427.
 
     """
-    if isinstance(eda_phasic, pd.DataFrame) or isinstance(eda_phasic, pd.Series):
+    if isinstance(eda_phasic, (pd.DataFrame, pd.Series)):
         try:
             eda_phasic = eda_phasic["EDA_Phasic"]
         except KeyError:
             eda_phasic = eda_phasic.values
 
     # Get basic
-    info = eda_findpeaks(eda_phasic, sampling_rate=sampling_rate, method=method, amplitude_min=0.1)
-    info = eda_fixpeaks(info, sampling_rate=sampling_rate)
+    info = eda_findpeaks(eda_phasic, sampling_rate=sampling_rate, method=method, amplitude_min=amplitude_min)
+    info = eda_fixpeaks(info)
 
     # Get additional features (rise time, half recovery time, etc.)
     info = _eda_peaks_getfeatures(info, eda_phasic, sampling_rate, recovery_percentage=0.5)
@@ -103,7 +103,9 @@ def _eda_peaks_getfeatures(info, eda_phasic, sampling_rate=1000, recovery_percen
     # Sanity checks -----------------------------------------------------------
 
     # Peaks (remove peaks with no onset)
-    valid_peaks = np.logical_and(info["SCR_Peaks"] > np.nanmin(info["SCR_Onsets"]), ~np.isnan(info["SCR_Onsets"]))
+    valid_peaks = np.logical_and(
+        info["SCR_Peaks"] > np.nanmin(info["SCR_Onsets"]), ~np.isnan(info["SCR_Onsets"])
+    )  # pylint: disable=E1111
     peaks = info["SCR_Peaks"][valid_peaks]
 
     # Onsets (remove onsets with no peaks)
