@@ -1,6 +1,4 @@
-"""
-Submodule for NeuroKit.
-"""
+"""Submodule for NeuroKit."""
 
 from .mne_channel_add import mne_channel_add
 from .mne_channel_extract import mne_channel_extract
