@@ -1,20 +1,18 @@
 # -*- coding: utf-8 -*-
 import numpy as np
-import pandas as pd
-import scipy.signal
 
 from ..signal import signal_filter
 
 
 def emg_amplitude(emg_cleaned):
-    """
-    Compute electromyography (EMG) amplitude.
+    """Compute electromyography (EMG) amplitude.
 
-    Compute electromyography amplitude given the cleaned respiration signal, done by calculating the linear envelope of the signal.
+    Compute electromyography amplitude given the cleaned respiration signal, done by calculating the
+    linear envelope of the signal.
 
     Parameters
     ----------
-    emg_cleaned : list, array or Series
+    emg_cleaned : list or array or Series
         The cleaned electromyography channel as returned by `emg_clean()`.
 
     Returns
@@ -29,6 +27,7 @@ def emg_amplitude(emg_cleaned):
     Examples
     --------
     >>> import neurokit2 as nk
+    >>> import pandas as pd
     >>>
     >>> emg = nk.emg_simulate(duration=10, sampling_rate=1000, burst_number=3)
     >>> cleaned = nk.emg_clean(emg, sampling_rate=1000)
@@ -48,8 +47,7 @@ def emg_amplitude(emg_cleaned):
 # Taeger-Kaiser Energy Operator
 # =============================================================================
 def _emg_amplitude_tkeo(emg_cleaned):
-    """
-    Calculates the Teager–Kaiser Energy operator to improve onset detection, described by Marcos Duarte at
+    """Calculates the Teager–Kaiser Energy operator to improve onset detection, described by Marcos Duarte at
     https://github.com/demotu/BMC/blob/master/notebooks/Electromyography.ipynb.
 
     Parameters
@@ -65,7 +63,9 @@ def _emg_amplitude_tkeo(emg_cleaned):
     References
     ----------
     - BMCLab: https://github.com/demotu/BMC/blob/master/notebooks/Electromyography.ipynb
-    - Li, X., Zhou, P., & Aruin, A. S. (2007). Teager–Kaiser energy operation of surface EMG improves muscle activity onset detection. Annals of biomedical engineering, 35(9), 1532-1538.
+
+    - Li, X., Zhou, P., & Aruin, A. S. (2007). Teager–Kaiser energy operation of surface EMG improves
+    muscle activity onset detection. Annals of biomedical engineering, 35(9), 1532-1538.
 
     """
     tkeo = emg_cleaned.copy()
@@ -83,21 +83,23 @@ def _emg_amplitude_tkeo(emg_cleaned):
 # Linear Envelope
 # =============================================================================
 def _emg_amplitude_envelope(emg_cleaned, sampling_rate=1000, lowcut=10, highcut=400, envelope_filter=8):
-    """
-    Calculate the linear envelope of a signal.
+    """Calculate the linear envelope of a signal.
 
-    This function implements a 2nd-order Butterworth filter with zero lag, described by Marcos Duarte at <https://github.com/demotu/BMC/blob/master/notebooks/Electromyography.ipynb>.
+    This function implements a 2nd-order Butterworth filter with zero lag, described by Marcos Duarte
+    at <https://github.com/demotu/BMC/blob/master/notebooks/Electromyography.ipynb>.
 
     Parameters
     ----------
-    emg_cleaned : list, array or Series
+    emg_cleaned : list or array or Series
         The cleaned electromyography channel as returned by `emg_clean()`.
     sampling_rate : int
         The sampling frequency of `emg_signal` (in Hz, i.e., samples/second).
-    freqs : list
-        Cutoff frequencies for the band-pass filter (in Hz). Defaults to [10, 400].
-    lfreq : float
-        Cutoff frequency for the low-pass filter (in Hz). Defaults to 8Hz.
+    lowcut : float
+        Low-cut frequency for the band-pass filter (in Hz). Defaults to 10Hz.
+    highcut : float
+        High-cut frequency for the band-pass filter (in Hz). Defaults to 400Hz.
+    envelope_filter : float
+        Cuttoff frequency for the high-pass filter (in Hz). Defauts to 8Hz.
 
     Returns
     -------
