@@ -8,21 +8,18 @@ from .hrv_utils import _hrv_get_rri, _hrv_sanitize_input
 
 
 def hrv_time(peaks, sampling_rate=1000, show=False):
-    """
-    Computes time-domain indices of Heart Rate Variability (HRV).
+    """Computes time-domain indices of Heart Rate Variability (HRV).
 
      See references for details.
 
     Parameters
     ----------
     peaks : dict
-        Samples at which cardiac extrema (i.e., R-peaks, systolic peaks) occur.
-        Dictionary returned by ecg_findpeaks, ecg_peaks, ppg_findpeaks, or
-        ppg_peaks.
+        Samples at which cardiac extrema (i.e., R-peaks, systolic peaks) occur. Dictionary returned
+        by ecg_findpeaks, ecg_peaks, ppg_findpeaks, or ppg_peaks.
     sampling_rate : int, optional
-        Sampling rate (Hz) of the continuous cardiac signal in which the peaks
-        occur. Should be at least twice as high as the highest frequency in vhf.
-        By default 1000.
+        Sampling rate (Hz) of the continuous cardiac signal in which the peaks occur. Should be at
+        least twice as high as the highest frequency in vhf. By default 1000.
     show : bool
         If True, will plot the distribution of R-R intervals.
 
@@ -30,19 +27,26 @@ def hrv_time(peaks, sampling_rate=1000, show=False):
     -------
     DataFrame
         Contains time domain HRV metrics:
-        - "*RMSSD*": the square root of the mean of the sum of successive differences between adjacent RR intervals.
+        - "*RMSSD*": the square root of the mean of the sum of successive differences between
+        adjacent RR intervals.
         - "*MeanNN*": the mean of the RR intervals.
         - "*SDNN*": the standard deviation of the RR intervals.
         - "*SDSD*": the standard deviation of the successive differences between RR intervals.
-        - "*CVNN*": the standard deviation of the RR intervals (SDNN) divided by the mean of the RR intervals (MeanNN).
-        - "*CVSD*": the root mean square of the sum of successive differences (RMSSD) divided by the mean of the RR intervals (MeanNN).
+        - "*CVNN*": the standard deviation of the RR intervals (SDNN) divided by the mean of the RR
+        intervals (MeanNN).
+        - "*CVSD*": the root mean square of the sum of successive differences (RMSSD) divided by the
+        mean of the RR intervals (MeanNN).
         - "*MedianNN*": the median of the absolute values of the successive differences between RR intervals.
         - "*MadNN*": the median absolute deviation of the RR intervals.
-        - "*HCVNN*": the median absolute deviation of the RR intervals (MadNN) divided by the median of the absolute differences of their successive differences (MedianNN).
+        - "*HCVNN*": the median absolute deviation of the RR intervals (MadNN) divided by the median
+        of the absolute differences of their successive differences (MedianNN).
         - "*pNN50*": the proportion of RR intervals greater than 50ms, out of the total number of RR intervals.
         - "*pNN20*": the proportion of RR intervals greater than 20ms, out of the total number of RR intervals.
-        - "*TINN*": a geometrical parameter of the HRV, or more specifically, the baseline width of the RR intervals distribution obtained by triangular interpolation, where the error of least squares determines the triangle. It is an approximation of the RR interval distribution.
-        - "*HTI*": the HRV triangular index, measuring the total number of RR intervals divded by the height of the RR intervals histogram.
+        - "*TINN*": a geometrical parameter of the HRV, or more specifically, the baseline width of
+        the RR intervals distribution obtained by triangular interpolation, where the error of least
+        squares determines the triangle. It is an approximation of the RR interval distribution.
+        - "*HTI*": the HRV triangular index, measuring the total number of RR intervals divded by the
+        height of the RR intervals histogram.
 
     See Also
     --------
@@ -63,10 +67,10 @@ def hrv_time(peaks, sampling_rate=1000, show=False):
 
     References
     ----------
-    - Stein, P. K. (2002). Assessing heart rate variability from real-world
-      Holter reports. Cardiac electrophysiology review, 6(3), 239-244.
-    - Shaffer, F., & Ginsberg, J. P. (2017). An overview of heart rate
-    variability metrics and norms. Frontiers in public health, 5, 258.
+    - Stein, P. K. (2002). Assessing heart rate variability from real-world Holter reports. Cardiac
+    electrophysiology review, 6(3), 239-244.
+    - Shaffer, F., & Ginsberg, J. P. (2017). An overview of heart rate variability metrics and norms.
+    Frontiers in public health, 5, 258.
 
     """
     # Sanitize input
@@ -80,14 +84,16 @@ def hrv_time(peaks, sampling_rate=1000, show=False):
 
     # Mean based
     out["RMSSD"] = np.sqrt(np.mean(diff_rri ** 2))
-    out["MeanNN"] = np.mean(rri)
-    out["SDNN"] = np.std(rri, ddof=1)
-    out["SDSD"] = np.std(diff_rri, ddof=1)
+
+    out["MeanNN"] = np.nanmean(rri)
+    out["SDNN"] = np.nanstd(rri, ddof=1)
+    out["SDSD"] = np.nanstd(diff_rri, ddof=1)
+
     out["CVNN"] = out["SDNN"] / out["MeanNN"]
     out["CVSD"] = out["RMSSD"] / out["MeanNN"]
 
     # Robust
-    out["MedianNN"] = np.median(np.abs(rri))
+    out["MedianNN"] = np.nanmedian(rri)
     out["MadNN"] = mad(rri)
     out["MCVNN"] = out["MadNN"] / out["MedianNN"]
 
