@@ -1,6 +1,4 @@
-"""
-Submodule for NeuroKit.
-"""
+"""Submodule for NeuroKit."""
 
 from .expspace import expspace
 from .find_closest import find_closest
