@@ -4,8 +4,7 @@ import pandas as pd
 
 
 def as_vector(x):
-    """
-    Convert to vector.
+    """Convert to vector.
 
     Examples
     --------
