@@ -1,31 +1,24 @@
 # -*- coding: utf-8 -*-
-import numpy as np
-import pandas as pd
 
 from ..signal import signal_interpolate
 from .rsp_fixpeaks import _rsp_fixpeaks_retrieve
 
 
 def rsp_amplitude(rsp_cleaned, peaks, troughs=None):
-    """
-    Compute respiratory amplitude.
+    """Compute respiratory amplitude.
 
-    Compute respiratory amplitude given the raw respiration signal and its
-    extrema.
+    Compute respiratory amplitude given the raw respiration signal and its extrema.
 
     Parameters
     ----------
-    rsp_cleaned : list, array or Series
+    rsp_cleaned : list or array or Series
         The cleaned respiration channel as returned by `rsp_clean()`.
-    peaks, troughs : list, array, DataFrame, Series or dict
-        The samples at which the inhalation peaks occur. If a dict or a
-        DataFrame is passed, it is assumed that these containers were obtained
-        with `rsp_findpeaks()`.
-    desired_length : int
-        By default, the returned respiration rate has the same number of
-        elements as `peaks`. If set to an integer, the returned rate will be
-        interpolated between `peaks` over `desired_length` samples. Has no
-        effect if a DataFrame is passed in as the `peaks` argument.
+    peaks : list or array or DataFrame or Series or dict
+        The samples at which the inhalation peaks occur. If a dict or a DataFrame is passed, it is
+        assumed that these containers were obtained with `rsp_findpeaks()`.
+    troughs : list or array or DataFrame or Series or dict
+        The samples at which the inhalation troughs occur. If a dict or a DataFrame is passed, it is
+        assumed that these containers were obtained with `rsp_findpeaks()`.
 
     Returns
     -------
@@ -39,6 +32,7 @@ def rsp_amplitude(rsp_cleaned, peaks, troughs=None):
     Examples
     --------
     >>> import neurokit2 as nk
+    >>> import pandas as pd
     >>>
     >>> rsp = nk.rsp_simulate(duration=90, respiratory_rate=15)
     >>> cleaned = nk.rsp_clean(rsp, sampling_rate=1000)
