@@ -7,25 +7,21 @@ from ..signal import signal_detrend, signal_filter
 
 
 def rsp_clean(rsp_signal, sampling_rate=1000, method="khodadad2018"):
-    """
-    Preprocess a respiration (RSP) signal.
+    """Preprocess a respiration (RSP) signal.
 
-    Clean a respiration signal using different sets of parameters, such as
-    'khodadad2018' (linear detrending followed by a fifth order 2Hz low-pass
-    IIR Butterworth filter) or `BioSPPy <https://github.com/PIA-Group/BioSPPy/blob/master/biosppy/signals/resp.py>`_
-    (second order 0.1 - 0.35 Hz bandpass Butterworth filter followed by a
-    constant detrending).
+    Clean a respiration signal using different sets of parameters, such as 'khodadad2018'
+    (linear detrending followed by a fifth order 2Hz low-pass IIR Butterworth filter) or
+    `BioSPPy <https://github.com/PIA-Group/BioSPPy/blob/master/biosppy/signals/resp.py>`_
+    (second order0.1 - 0.35 Hz bandpass Butterworth filter followed by a constant detrending).
 
     Parameters
     ----------
     rsp_signal : list, array or Series
-        The raw respiration channel (as measured, for instance, by a
-        respiration belt).
+        The raw respiration channel (as measured, for instance, by a respiration belt).
     sampling_rate : int
         The sampling frequency of `rsp_signal` (in Hz, i.e., samples/second).
     method : str
-        The processing pipeline to apply. Can be one of "khodadad2018"
-        (default) or "biosppy".
+        The processing pipeline to apply. Can be one of "khodadad2018" (default) or "biosppy".
 
     Returns
     -------
@@ -42,7 +38,9 @@ def rsp_clean(rsp_signal, sampling_rate=1000, method="khodadad2018"):
     >>> import neurokit2 as nk
     >>>
     >>> rsp = nk.rsp_simulate(duration=30, sampling_rate=50, noise=0.01)
-    >>> signals = pd.DataFrame({ "RSP_Raw": rsp, "RSP_Khodadad2018": nk.rsp_clean(rsp, sampling_rate=50, method="khodadad2018"), "RSP_BioSPPy": nk.rsp_clean(rsp, sampling_rate=50, method="biosppy")})
+    >>> signals = pd.DataFrame({ "RSP_Raw": rsp,
+    ...                         "RSP_Khodadad2018": nk.rsp_clean(rsp, sampling_rate=50, method="khodadad2018"),
+    ...                         "RSP_BioSPPy": nk.rsp_clean(rsp, sampling_rate=50, method="biosppy")})
     >>> fig = signals.plot()
     >>> fig #doctest: +SKIP
 
@@ -68,8 +66,7 @@ def rsp_clean(rsp_signal, sampling_rate=1000, method="khodadad2018"):
 # Khodadad et al. (2018)
 # =============================================================================
 def _rsp_clean_khodadad2018(rsp_signal, sampling_rate=1000):
-    """
-    The algorithm is based on (but not an exact implementation of) the "Zero-crossing algorithm with amplitude
+    """The algorithm is based on (but not an exact implementation of) the "Zero-crossing algorithm with amplitude
     threshold" by `Khodadad et al. (2018)
 
     <https://iopscience.iop.org/article/10.1088/1361-6579/aad7e6/meta>`_.
@@ -94,8 +91,7 @@ def _rsp_clean_khodadad2018(rsp_signal, sampling_rate=1000):
 # BioSPPy
 # =============================================================================
 def _rsp_clean_biosppy(rsp_signal, sampling_rate=1000):
-    """
-    Uses the same defaults as `BioSPPy.
+    """Uses the same defaults as `BioSPPy.
 
     <https://github.com/PIA-Group/BioSPPy/blob/master/biosppy/signals/resp.py>`_.
 
