@@ -7,33 +7,30 @@ from .rsp_fixpeaks import _rsp_fixpeaks_retrieve
 
 
 def rsp_phase(peaks, troughs=None, desired_length=None):
-    """
-    Compute respiratory phase (inspiration and expiration).
+    """Compute respiratory phase (inspiration and expiration).
 
     Finds the respiratory phase, labelled as 1 for inspiration and 0 for expiration.
+
     Parameters
     ----------
-    peaks, troughs : list, array, DataFrame, Series or dict
-        The samples at which the inhalation peaks occur. If a dict or a
-        DataFrame is passed, it is assumed that these containers were obtained
-        with `rsp_findpeaks()`.
+    peaks : list or array or DataFrame or Series or dict
+        The samples at which the inhalation peaks occur. If a dict or a DataFrame is passed, it is
+        assumed that these containers were obtained with `rsp_findpeaks()`.
+    troughs : list or array or DataFrame or Series or dict
+        The samples at which the inhalation troughs occur. If a dict or a DataFrame is passed, it is
+        assumed that these containers were obtained with `rsp_findpeaks()`.
     desired_length : int
-        By default, the returned respiration rate has the same number of
-        elements as `peaks`. If set to an integer, the returned rate will be
-        interpolated between `peaks` over `desired_length` samples. Has no
-        effect if a DataFrame is passed in as the `peaks` argument.
+        By default, the returned respiration rate has the same number of elements as `peaks`. If set
+        to an integer, the returned rate will be interpolated between `peaks` over `desired_length`
+        samples. Has no effect if a DataFrame is passed in as the `peaks` argument.
 
     Returns
     -------
     signals : DataFrame
-        A DataFrame of same length as `rsp_signal` containing the following
-        columns:
-
-        - *"RSP_Inspiration"*: breathing phase, marked by "1" for inspiration
-          and "0" for expiration.
-        - *"RSP_Phase_Completion"*: breathing phase completion, expressed in
-          percentage (from 0 to 1), representing the stage of the current
-          respiratory phase.
+        A DataFrame of same length as `rsp_signal` containing the following columns:
+        - *"RSP_Inspiration"*: breathing phase, marked by "1" for inspiration and "0" for expiration.
+        - *"RSP_Phase_Completion"*: breathing phase completion, expressed in percentage (from 0 to 1),
+        representing the stage of the current respiratory phase.
 
     See Also
     --------
