@@ -9,51 +9,42 @@ from .rsp_phase import rsp_phase
 
 
 def rsp_process(rsp_signal, sampling_rate=1000, method="khodadad2018"):
-    """
-    Process a respiration (RSP) signal.
+    """Process a respiration (RSP) signal.
 
-    Convenience function that automatically processes a respiration signal with
-    one of the following methods:
+    Convenience function that automatically processes a respiration signal with one of the following methods:
 
     - `Khodadad et al. (2018)
     <https://iopscience.iop.org/article/10.1088/1361-6579/aad7e6/meta>`_
+
     - `BioSPPy
     <https://github.com/PIA-Group/BioSPPy/blob/master/biosppy/signals/resp.py>`_
 
     Parameters
     ----------
     rsp_signal : list, array or Series
-        The raw respiration channel (as measured, for instance, by a
-        respiration belt).
+        The raw respiration channel (as measured, for instance, by a respiration belt).
     sampling_rate : int
         The sampling frequency of `rsp_signal` (in Hz, i.e., samples/second).
     method : str
-        The processing pipeline to apply. Can be one of "khodadad2018"
-        (default) or "biosppy".
+        The processing pipeline to apply. Can be one of "khodadad2018" (default) or "biosppy".
 
     Returns
     -------
     signals : DataFrame
         A DataFrame of same length as `rsp_signal` containing the following
         columns:
-
         - *"RSP_Raw"*: the raw signal.
         - *"RSP_Clean"*: the cleaned signal.
         - *"RSP_Peaks"*: the inhalation peaks marked as "1" in a list of zeros.
-        - *"RSP_Troughs"*: the exhalation troughs marked as "1" in a list of
-          zeros.
+        - *"RSP_Troughs"*: the exhalation troughs marked as "1" in a list of zeros.
         - *"RSP_Rate"*: breathing rate interpolated between inhalation peaks.
-        - *"RSP_Amplitude"*: breathing amplitude interpolated between
-          inhalation peaks.
-        - *"RSP_Phase"*: breathing phase, marked by "1" for inspiration
-          and "0" for expiration.
-        - *"RSP_PhaseCompletion"*: breathing phase completion, expressed in
-          percentage (from 0 to 1), representing the stage of the current
-          respiratory phase.
+        - *"RSP_Amplitude"*: breathing amplitude interpolated between inhalation peaks.
+        - *"RSP_Phase"*: breathing phase, marked by "1" for inspiration and "0" for expiration.
+        - *"RSP_PhaseCompletion"*: breathing phase completion, expressed in percentage (from 0 to 1),
+        representing the stage of the current respiratory phase.
     info : dict
-        A dictionary containing the samples at which inhalation peaks and
-        exhalation troughs occur, accessible with the keys "RSP_Peaks", and
-        "RSP_Troughs", respectively.
+        A dictionary containing the samples at which inhalation peaks and exhalation troughs occur,
+        accessible with the keys "RSP_Peaks", and "RSP_Troughs", respectively.
 
     See Also
     --------
