@@ -21,8 +21,7 @@ def signal_distort(
     random_state=None,
     silent=False,
 ):
-    """
-    Signal distortion.
+    """Signal distortion.
 
     Add noise of a given frequency, amplitude and shape to a signal.
 
@@ -75,11 +74,19 @@ def signal_distort(
     >>> signal = nk.signal_simulate(duration=10, frequency=0.5)
     >>>
     >>> # Noise
-    >>> noise = pd.DataFrame({"Freq100": nk.signal_distort(signal, noise_frequency=200), "Freq50": nk.signal_distort(signal, noise_frequency=50), "Freq10": nk.signal_distort(signal, noise_frequency=10), "Freq5": nk.signal_distort(signal, noise_frequency=5),"Raw": signal}).plot()
+    >>> noise = pd.DataFrame({"Freq100": nk.signal_distort(signal, noise_frequency=200),
+    ...                       "Freq50": nk.signal_distort(signal, noise_frequency=50),
+    ...                       "Freq10": nk.signal_distort(signal, noise_frequency=10),
+    ...                       "Freq5": nk.signal_distort(signal, noise_frequency=5),
+    ...                       "Raw": signal}).plot()
     >>> noise #doctest: +SKIP
     >>>
     >>> # Artifacts
-    >>> artifacts = pd.DataFrame({"1Hz": nk.signal_distort(signal, noise_amplitude=0, artifacts_frequency=1, artifacts_amplitude=0.5), "5Hz": nk.signal_distort(signal, noise_amplitude=0, artifacts_frequency=5, artifacts_amplitude=0.2), "Raw": signal}).plot()
+    >>> artifacts = pd.DataFrame({"1Hz": nk.signal_distort(signal, noise_amplitude=0,
+    ...                                                    artifacts_frequency=1, artifacts_amplitude=0.5),
+    ...                           "5Hz": nk.signal_distort(signal, noise_amplitude=0,
+    ...                                                    artifacts_frequency=5, artifacts_amplitude=0.2),
+    ...                           "Raw": signal}).plot()
     >>> artifacts #doctest: +SKIP
 
     """
