@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
 import numpy as np
-import pandas as pd
 
 from .signal_resample import signal_resample
 
 
 def signal_merge(signal1, signal2, time1=[0, 10], time2=[0, 10]):
-    """
-    Arbitrary addition of two signals with different time ranges.
+    """Arbitrary addition of two signals with different time ranges.
 
     Parameters
     ----------
     signal1, signal2 : list, array or Series
         The signal (i.e., a time series)s in the form of a vector of values.
     time1, time2 : list
-        Lists containing two numeric values corresponding to the beginning and end of 'signal1' and 'signal2', respectively.
+        Lists containing two numeric values corresponding to the beginning and end of 'signal1' and
+        'signal2', respectively.
 
     Returns
     -------
