@@ -7,8 +7,7 @@ from ..stats import fit_loess
 
 
 def signal_smooth(signal, method="convolution", kernel="boxzen", size=10, alpha=0.1):
-    """
-    Signal smoothing.
+    """Signal smoothing.
 
     Signal smoothing can be achieved using either the convolution of a filter kernel with the input
     signal to compute the smoothed signal (Smith, 1997) or a LOESS regression.
@@ -20,12 +19,11 @@ def signal_smooth(signal, method="convolution", kernel="boxzen", size=10, alpha=
     method : str
         Can be one of 'convolution' (default) or 'loess'.
     kernel : str, array
-        Only used if `method` is 'convolution'. Type of kernel to use; if array, use directly as the kernel. Can be one
-        of 'median', 'boxzen', 'boxcar', 'triang', 'blackman', 'hamming',
-        'hann', 'bartlett', 'flattop', 'parzen', 'bohman', 'blackmanharris',
-        'nuttall', 'barthann', 'kaiser' (needs beta), 'gaussian' (needs std),
-        'general_gaussian' (needs power, width), 'slepian' (needs width) or
-        'chebwin' (needs attenuation).
+        Only used if `method` is 'convolution'. Type of kernel to use; if array, use directly as the
+        kernel. Can be one of 'median', 'boxzen', 'boxcar', 'triang', 'blackman', 'hamming', 'hann',
+        'bartlett', 'flattop', 'parzen', 'bohman', 'blackmanharris', 'nuttall', 'barthann', 'kaiser'
+        (needs beta), 'gaussian' (needs std), 'general_gaussian' (needs power, width), 'slepian' (needs width)
+        or 'chebwin' (needs attenuation).
     size : int
         Only used if `method` is 'convolution'. Size of the kernel; ignored if kernel is an array.
     alpha : float
@@ -51,15 +49,21 @@ def signal_smooth(signal, method="convolution", kernel="boxzen", size=10, alpha=
     >>> distorted = nk.signal_distort(signal, noise_amplitude=[0.3, 0.2, 0.1, 0.05], noise_frequency=[5, 10, 50, 100])
     >>>
     >>> size = len(signal)/100
-    >>> signals = pd.DataFrame({"Raw": distorted, "Median": nk.signal_smooth(distorted, kernel='median', size=size-1), "BoxZen": nk.signal_smooth(distorted, kernel='boxzen', size=size), "Triang": nk.signal_smooth(distorted, kernel='triang', size=size), "Blackman": nk.signal_smooth(distorted, kernel='blackman', size=size), "Loess_01": nk.signal_smooth(distorted, method='loess', alpha=0.1), "Loess_02": nk.signal_smooth(distorted, method='loess', alpha=0.2), "Loess_05": nk.signal_smooth(distorted, method='loess', alpha=0.5)})
+    >>> signals = pd.DataFrame({"Raw": distorted,
+    ...                         "Median": nk.signal_smooth(distorted, kernel='median', size=size-1),
+    ...                         "BoxZen": nk.signal_smooth(distorted, kernel='boxzen', size=size),
+    ...                         "Triang": nk.signal_smooth(distorted, kernel='triang', size=size),
+    ...                         "Blackman": nk.signal_smooth(distorted, kernel='blackman', size=size),
+    ...                         "Loess_01": nk.signal_smooth(distorted, method='loess', alpha=0.1),
+    ...                         "Loess_02": nk.signal_smooth(distorted, method='loess', alpha=0.2),
+    ...                         "Loess_05": nk.signal_smooth(distorted, method='loess', alpha=0.5)})
     >>> fig = signals.plot()
     >>> fig_magnify = signals[50:150].plot()  # Magnify
     >>> fig_magnify #doctest: +SKIP
 
     References
     ----------
-    - Smith, S. W. (1997). The scientist and engineer's guide to digital signal
-    processing.
+    - Smith, S. W. (1997). The scientist and engineer's guide to digital signal processing.
 
     """
     if isinstance(signal, pd.Series):
