@@ -5,8 +5,7 @@ import scipy.stats
 
 
 def density(x, desired_length=100, bandwith=1, show=False):
-    """
-    Density estimation.
+    """Density estimation.
 
     Computes kernel density estimates.
 
