@@ -8,8 +8,7 @@ from .standardize import standardize
 
 
 def distance(X=None, method="mahalanobis"):
-    """
-    Distance.
+    """Distance.
 
     Compute distance using different metrics.
 
@@ -19,8 +18,7 @@ def distance(X=None, method="mahalanobis"):
     X : array or DataFrame
         A dataframe of values.
     method : str
-        The method to use. One of 'mahalanobis' or 'mean' for
-        the average distance from the mean.
+        The method to use. One of 'mahalanobis' or 'mean' for the average distance from the mean.
 
     Returns
     -------
