@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
 import numpy as np
-import pandas as pd
 
 
 def rescale(data, to=[0, 1]):
-    """
-    Rescale data.
+    """Rescale data.
 
     Rescale a numeric variable to a new range.
 
